@@ -3,7 +3,7 @@
 #
 # Copyright (C) 1998, 1999 Albert Hopkins (marduk)
 # Copyright (C) 2002 Mike Meyer
-# Copyright (C) 2005, 2006, 2007 Arthur de Jong
+# Copyright (C) 2005, 2006, 2007, 2008, 2010 Arthur de Jong
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -30,10 +30,10 @@ items should be changeble from the command line."""
 import urllib
 
 # Current version of webcheck.
-VERSION = '1.10.2'
+VERSION = '1.10.4'
 
 # The homepage of webcheck.
-HOMEPAGE = 'http://ch.tudelft.nl/~arthur/webcheck/'
+HOMEPAGE = 'http://arthurdejong.org/webcheck/'
 
 # Whether to consider any URL not starting with the base URL to be external.
 # This is the state of the -b command line option.
@@ -104,6 +104,9 @@ REPORT_WHATSNEW_URL_AGE = 7
 # The size of a page in kilobytes after which the page is considered too big.
 REPORT_SLOW_URL_SIZE = 76
 
+# The maximum number of links to show in the "referenced from:" lists
+PARENT_LISTLEN = 10
+
 # Whether to open links in a new window (add target="_blank")
 # (disabled by default because it is not xhtml 1.1)
 REPORT_LINKS_IN_NEW_WINDOW = False
@@ -119,3 +122,16 @@ FTP_INDEXES = [ 'index.html', 'index.htm' ]
 # Whether to fetch robots.txt files and do checking based on the information
 # present in those files (normally matching links are yanked).
 USE_ROBOTS = True
+
+# This is a hash that maps netlocs (e.g. some.server.com:8000) to
+# username/password combinations that are passed as basic authentication
+# to that netloc
+USERPASS = {}
+
+# Options for tidy (make None to disable running tidy)
+# See http://tidy.sourceforge.net/docs/quickref.html for details.
+TIDY_OPTIONS = dict(quiet=1,
+                    accessibility_check=1,
+                    show_errors=6,
+                    show_warnings=1,
+                    char_encoding='raw')
