@@ -3,7 +3,7 @@
 #
 # Copyright (C) 1998, 1999 Albert Hopkins (marduk)
 # Copyright (C) 2002 Mike W. Meyer
-# Copyright (C) 2005, 2006, 2007 Arthur de Jong
+# Copyright (C) 2005, 2006, 2007, 2008 Arthur de Jong
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -253,6 +253,8 @@ class Site:
             serfp.flush()
 
     def postprocess(self):
+        """Do some basic post processing of the collected data, including
+        depth of every link."""
         # build the list of urls that were set up with add_internal() that
         # do not have a parent (they form the base for the site)
         for url in self._internal_urls:
@@ -508,8 +510,10 @@ class Link:
         # only think about problems on internal pages
         if not self.isinternal:
             return
-        self.pageproblems.append(problem)
-        self._ischanged = True
+        # only include a single problem once (e.g. multiple anchors)
+        if problem not in self.pageproblems:
+            self.pageproblems.append(problem)
+            self._ischanged = True
 
     def fetch(self):
         """Attempt to fetch the url (if isyanked is not True) and fill in link
@@ -541,7 +545,13 @@ class Link:
             return
         # parse the content
         debugio.debug('crawler.Link.fetch(): parsing using %s' % parsermodule.__name__)
-        parsermodule.parse(content, self)
+        try:
+            parsermodule.parse(content, self)
+        except Exception, e:
+            self.add_pageproblem('problem parsing page: ' + str(e))
+            debugio.warn('problem parsing page: ' + str(e))
+            import traceback
+            traceback.print_exc()
 
     def follow_link(self, visited=set()):
         """If this link represents a redirect return the redirect target,
