@@ -51,6 +51,9 @@ _urlprobpattern = re.compile('([^-;/?:@&=+$,%#.0123456789' \
 # pattern for double slashes
 _doubleslashpattern = re.compile('//+')
 
+# pattern for leading dots
+_leadingdotpattern = re.compile('^(/\.\.)*')
+
 def _unescape_printable(match):
     """Helper function for _normalize_escapes() to perform the expansion of
     html entity refs that are normal printable (but not reserver)
@@ -81,12 +84,21 @@ def _urlclean(url):
     url = _normalize_escapes(url)
     # split the url in useful parts
     (scheme, netloc, path, query) = urlparse.urlsplit(url)[:4]
+    # remove any leading /../ parts
+    if scheme in ( 'http', 'https' ):
+        path = _leadingdotpattern.sub('', path)
     if ( scheme == 'http' or scheme == 'https' or scheme == 'ftp' ):
         # http(s) urls should have a non-empty path
         if path == '':
             path = '/'
         # make hostname lower case
         (userpass, hostport) = urllib.splituser(netloc)
+        (host, port) = urllib.splitport(hostport)
+        # remove default port
+        if scheme == 'http' and str(port) == '80':
+            hostport = host
+        elif scheme == 'https' and str(port) == '443':
+            hostport = host
         netloc = hostport.lower()
         # trim trailing :
         if netloc[-1:] == ':':
