@@ -1,7 +1,7 @@
 
 # html.py - parser functions for html content
 #
-# Copyright (C) 2005, 2006, 2007 Arthur de Jong
+# Copyright (C) 2005, 2006, 2007, 2009 Arthur de Jong
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -200,6 +200,17 @@ class _MyHTMLParser(HTMLParser.HTMLParser):
         # <style>content</style>
         elif tag == 'style':
             self.collect = ''
+        # <script src="url">
+        elif tag == 'script' and attrs.has_key('src'):
+            self.embedded.append(self._cleanurl(attrs['src']))
+        # <body|table|td background="url">
+        elif tag in ('body', 'table', 'td') and attrs.has_key('background'):
+            self.embedded.append(self._cleanurl(attrs['background']))
+        # pick up any tags with a style attribute
+        if attrs.has_key('style'):
+            # delegate handling of inline css to css module
+            import parsers.css
+            parsers.css.parse(attrs['style'], self.link, self.base)
 
     def handle_endtag(self, tag):
         """Handle end tags in html."""
@@ -209,7 +220,7 @@ class _MyHTMLParser(HTMLParser.HTMLParser):
         elif tag == 'style' and self.collect is not None:
             # delegate handling of inline css to css module
             import parsers.css
-            parsers.css.parse(self.collect, self.link)
+            parsers.css.parse(self.collect, self.link, self.base)
 
     def handle_data(self, data):
         """Collect data if we were collecting data."""
