@@ -3,7 +3,7 @@
 #
 # Copyright (C) 1998, 1999 Albert Hopkins (marduk)
 # Copyright (C) 2002 Mike W. Meyer
-# Copyright (C) 2005, 2006, 2007 Arthur de Jong
+# Copyright (C) 2005, 2006, 2007, 2009 Arthur de Jong
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -159,10 +159,18 @@ def print_parents(fp, link, indent='     '):
       indent+'<div class="parents">\n'+
       indent+' referenced from:\n'+
       indent+' <ul>\n' )
+    more = 0
+    if len(parents) > config.PARENT_LISTLEN+1:
+        more = len(parents) - config.PARENT_LISTLEN
+        parents = parents[:config.PARENT_LISTLEN]
     for parent in parents:
         fp.write(
           indent+'  <li>%(parent)s</li>\n'
           % { 'parent': make_link(parent) })
+    if more:
+        fp.write(
+          indent+'  <li>%(more)d more...</li>\n'
+          % { 'more': more })
     fp.write(
       indent+' </ul>\n'+
       indent+'</div>\n' )
