@@ -3,7 +3,7 @@
 #
 # Copyright (C) 1998, 1999 Albert Hopkins (marduk)
 # Copyright (C) 2002 Mike W. Meyer
-# Copyright (C) 2005 Arthur de Jong
+# Copyright (C) 2005, 2006 Arthur de Jong
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -26,27 +26,32 @@
 
 __title__ = 'images'
 __author__ = 'Arthur de Jong'
+__outputfile__ = 'images.html'
 
 import plugins
 import re
 
-def generate(fp,site):
+def generate(site):
     """Output a list of images to the given file descriptor."""
-    # get all non-page links that have a mimetype
-    links = filter(lambda a: not a.ispage and a.mimetype is not None, site.linkMap.values())
     # this finds all links with a reasonable image-like content-type
-    matcher=re.compile("^image/.*$")
-    # get images
-    links = filter(lambda a: matcher.search(a.mimetype), links)
+    matcher = re.compile('^image/.*$')
+    # get non-page images that have an image/* mimetype
+    links = [ x
+              for x in site.linkMap.values()
+              if not x.ispage and
+                     x.mimetype is not None and
+                     matcher.search(x.mimetype) ]
     # sort list
     links.sort(lambda a, b: cmp(a.url, b.url))
     # present results
+    fp = plugins.open_html(plugins.images, site)
     if not links:
         fp.write(
           '   <p class="description">\n'
           '    No images were linked on the website.\n'
           '   </p>\n'
           '   <ol>\n' )
+        plugins.close_html(fp)
         return
     fp.write(
       '   <p class="description">\n'
@@ -54,6 +59,7 @@ def generate(fp,site):
       '   </p>\n'
       '   <ol>\n' )
     for link in links:
-        fp.write('    <li>%s</li>\n' % plugins.make_link(link,link.url))
+        fp.write('    <li>%s</li>\n' % plugins.make_link(link, link.url))
     fp.write(
       '   </ol>\n' )
+    plugins.close_html(fp)
