@@ -3,7 +3,7 @@
 #
 # Copyright (C) 1998, 1999 Albert Hopkins (marduk)
 # Copyright (C) 2002 Mike W. Meyer
-# Copyright (C) 2005 Arthur de Jong
+# Copyright (C) 2005, 2006 Arthur de Jong
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -26,20 +26,25 @@
 
 __title__ = 'not checked'
 __author__ = 'Arthur de Jong'
+__outputfile__ = 'notchkd.html'
 
 import plugins
 
-def generate(fp,site):
+def generate(site):
     """Output the list of not checked pages to the given file descriptor."""
     # get all yanked urls
-    links = filter(lambda a: a.isyanked, site.linkMap.values())
+    links = [ x
+              for x in site.linkMap.values()
+              if x.isyanked ]
     links.sort(lambda a, b: cmp(a.url, b.url))
     # present results
+    fp = plugins.open_html(plugins.notchkd, site)
     if not links:
         fp.write(
           '   <p class="description">\n'
           '    All links have been checked.\n'
           '   </p>\n' )
+        plugins.close_html(fp)
         return
     fp.write(
       '   <p class="description">\n'
@@ -51,10 +56,11 @@ def generate(fp,site):
         fp.write(
           '    <li>\n'
           '     %(link)s\n'
-          % { 'link': plugins.make_link(link,link.url) })
+          % { 'link': plugins.make_link(link, link.url) })
         # present a list of parents
-        plugins.print_parents(fp,link,'     ')
+        plugins.print_parents(fp, link, '     ')
         fp.write(
           '    </li>\n')
     fp.write(
       '   </ol>\n' )
+    plugins.close_html(fp)
