@@ -3,7 +3,7 @@
 #
 # Copyright (C) 1998, 1999 Albert Hopkins (marduk)
 # Copyright (C) 2002 Mike W. Meyer
-# Copyright (C) 2005 Arthur de Jong
+# Copyright (C) 2005, 2006 Arthur de Jong
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -26,20 +26,27 @@
 
 __title__ = 'missing titles'
 __author__ = 'Arthur de Jong'
+__outputfile__ = 'notitles.html'
 
 import plugins
 
-def generate(fp,site):
+def generate(site):
     """Output the list of pages without a title to the given file descriptor."""
     # get all internal pages without a title
-    links = filter(lambda a: a.ispage and a.isinternal and a.title is None, site.linkMap.values())
+    links = [ x
+              for x in site.linkMap.values()
+              if x.ispage and
+                 x.isinternal and
+                 (x.title is None or x.title == '') ]
     links.sort(lambda a, b: cmp(a.url, b.url))
     # present results
+    fp = plugins.open_html(plugins.notitles, site)
     if not links:
         fp.write(
           '   <p class="description">\n'
           '    All pages had a title specified.\n'
           '   </p>\n' )
+        plugins.close_html(fp)
         return
     fp.write(
       '   <p class="description">\n'
@@ -51,6 +58,7 @@ def generate(fp,site):
         fp.write(
           '    <li>%(link)s</li>\n'
           % { 'link': plugins.make_link(link,link.url) })
-        link.add_pageproblem("missing title")
+        link.add_pageproblem('missing title')
     fp.write(
       '   </ol>\n' )
+    plugins.close_html(fp)
