@@ -4,7 +4,7 @@
 #
 # Copyright (C) 1998, 1999 Albert Hopkins (marduk)
 # Copyright (C) 2002 Mike W. Meyer
-# Copyright (C) 2005, 2006, 2007, 2008 Arthur de Jong
+# Copyright (C) 2005, 2006, 2007, 2008, 2010 Arthur de Jong
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -44,8 +44,8 @@ def print_version():
       'webcheck %(version)s\n'
       'Written by Albert Hopkins (marduk), Mike W. Meyer and Arthur de Jong.\n'
       '\n'
-      'Copyright (C) 1998, 1999, 2002, 2005, 2006, 2007, 2008 Albert Hopkins (marduk),\n'
-      'Mike W. Meyer and Arthur de Jong.\n'
+      'Copyright (C) 1998, 1999, 2002, 2005, 2006, 2007, 2008, 2009, 2010\n'
+      'Albert Hopkins (marduk), Mike W. Meyer and Arthur de Jong.\n'
       'This is free software; see the source for copying conditions.  There is NO\n'
       'warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n'
       % { 'version': config.VERSION })
@@ -130,7 +130,6 @@ def parse_args(site):
                 (_scheme, _netloc, _path, _params, _query, _frag) = urlparse.urlparse(arg)
                 (_userpass, _netloc) = urllib.splituser(_netloc)
                 config.USERPASS[_netloc] = _userpass
-                print config.USERPASS
             elif flag in ('-w', '--wait'):
                 config.WAIT_BETWEEN_REQUESTS = float(arg)
             elif flag in ('-V', '--version'):
